import 'dart:developer' as developer;
import 'dart:io' show Platform;

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'apptics_flutter_platform_interface.dart';
import 'apptics_flutter_util.dart';

/// An implementation of [AppticsFlutterPlatform] that uses method channels.

class MethodChannelAppticsFlutter extends AppticsFlutterPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('apptics_flutter');

  @override
  Future<void> setCrashCustomProperty(Map<String, dynamic> properties) async {
    if (Platform.isIOS) {
      methodChannel
          .invokeMethod('setCrashCustomProperty', {"properties": properties});
    } else {
      methodChannel
          .invokeMethod('setCrashCustomProperty', {"properties": properties});
    }
  }

  @override
  Future<void> presentPrivacyReviewPopup() async {
    if (Platform.isIOS) {
      methodChannel.invokeMethod('presentPrivacyReviewPopup');
    } else {
      methodChannel.invokeMethod('presentPrivacyReviewPopup');
    }
  }

  @override
  Future<void> openPrivacySettings() async {
    if (Platform.isIOS) {
      methodChannel.invokeMethod<void>('openPrivacySettings');
    } else {
      methodChannel.invokeMethod<void>('openPrivacySettings');
    }
  }

  @override
  Future<void> setUser(String? user_id) async {
    if (Platform.isIOS) {
      methodChannel.invokeMethod<void>('setUser', {"user_id": user_id});
    } else {
      methodChannel.invokeMethod<void>('setUser', {"userId": user_id});
    }
  }

  @override
  Future<TrackingState?> getTrackingState() async {
    int status =
        await methodChannel.invokeMethod<int>('getTrackingState') ?? -1;
    return TrackingState.getByValue(status);
  }

  @override
  Future<void> setTrackingState(TrackingState status) async {
    if (Platform.isIOS) {
      methodChannel
          .invokeMethod<void>('setTrackingState', {"status": status.value});
    } else {
      methodChannel
          .invokeMethod<void>('setTrackingState', {"status": status.value});
    }
  }

  @override
  Future<bool?> isUserLoggedIn() async {
    if (Platform.isIOS) {
      return await methodChannel.invokeMethod<bool>('isUserLoggedIn');
    } else {
      return await methodChannel.invokeMethod("isUserLoggedIn");
    }
  }

  @override
  Future<void> addEvent(
      String? event, String? group, Map<String, dynamic>? properties) async {
    if (Platform.isIOS) {
      methodChannel.invokeMethod<void>('addEvent',
          {"event": event, "group": group, "properties": properties});
    } else {
      methodChannel.invokeMethod<void>('addEvent',
          {"event": event, "group": group, "properties": properties});
    }
  }

  @override
  Future<void> screenAttached(String screen_name) async {
    if (Platform.isIOS) {
      methodChannel
          .invokeMethod<void>('screenAttached', {"screen_name": screen_name});
    } else {
      methodChannel
          .invokeMethod<void>('screenAttached', {"screen_name": screen_name});
    }
  }

  @override
  Future<void> screenDetached(String screen_name) async {
    if (Platform.isIOS) {
      methodChannel
          .invokeMethod<void>('screenDetached', {"screen_name": screen_name});
    } else {
      methodChannel
          .invokeMethod<void>('screenDetached', {"screen_name": screen_name});
    }
  }

  @override
  Future<void> showLastSessionCrashedPopup() async {
    if (Platform.isAndroid) {
      await methodChannel.invokeMethod<String>('showLastSessionCrashedPopup');
    }
  }
  @override
  Future<void> setDefaultLanguage(String lang) async {
    if (Platform.isIOS) {
      methodChannel.invokeMethod<void>('setDefaultLanguage', {"lang": lang});
    } else {
      developer.log('method not available', name: 'Apptics');
    }
  }

}
